@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '0.15';
+$VERSION = '0.24';
 
 #----------------------------------------------------------------------------
 
@@ -158,6 +158,12 @@ sub new {
     return $atts;
 }
 
+=head2 DESTROY
+
+Free unused Win32::OLE libraries
+
+=cut
+
 sub DESTROY {
     Win32::OLE->FreeUnusedLibraries();
 }
@@ -189,6 +195,26 @@ sub folder {
     $self->{objfolder} = Mail::Outlook::Folder->new($self,$foldername);
 }
 
+=head2 all_accounts
+
+Return a list of the available accounts. Each element is a hash ref with two
+keys: address and account. "address" is the SMPT address, "account" is the Account
+object.
+
+=cut
+
+sub all_accounts {
+  my $self = shift;
+  my $session = $self->{namespace}->Session || return;
+  my $accounts = $session->Accounts || return;
+  my @smtp_addresses = ();
+  for ( my $i=1;$i<=$accounts->{Count};$i++ ) {
+    my $item = $accounts->Item($i);
+    push( @smtp_addresses, { address => $item->smtpAddress, account => $item } );  
+  }
+  return @smtp_addresses;  
+}
+
 =head2 create(%hash)
 
 Creates a new message. Option hash table can be used. Returns the new message
@@ -243,14 +269,6 @@ Outlook (R) installed.
   Win32::OLE
   Win32::OLE::Const
 
-=head1 DSLIP
-
-  b - Beta testing
-  d - Developer
-  p - Perl-only
-  O - Object oriented
-  p - Standard-Perl: user may choose between GPL and Artistic
-
 =head1 BUGS, PATCHES & FIXES
 
 There are no known bugs at the time of this release. However, if you spot a
@@ -259,7 +277,7 @@ documentation, please submit a bug to the RT system (see link below). However,
 it would help greatly if you are able to pinpoint problems or even supply a
 patch.
 
-Fixes are dependant upon their severity and my availablity. Should a fix not
+Fixes are dependent upon their severity and my availability. Should a fix not
 be forthcoming, please feel free to (politely) remind me by sending an email
 to barbie@cpan.org .
 
@@ -272,13 +290,9 @@ RT: L<http://rt.cpan.org/Public/Dist/Display.html?Name=Mail-Outlook>
 
 =head1 COPYRIGHT AND LICENSE
 
-  Copyright  2003-2007 Barbie for Miss Barbell Productions.
+  Copyright E<copy> 2003-2013 Barbie for Miss Barbell Productions.
 
-  This library is free software; you can redistribute it and/or modify it under
-  the same terms as Perl itself, using the Artistic License.
-
-The full text of the licenses can be found in the Artistic file included with
-this distribution, or in perlartistic file as part of Perl installation, in
-the 5.8.1 release or later.
+  This distribution is free software; you can redistribute it and/or
+  modify it under the Artistic License v2.
 
 =cut
