@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '0.16';
+$VERSION = '0.24';
 
 #----------------------------------------------------------------------------
 
@@ -92,10 +92,9 @@ sub new {
         eval { $hash = $mailbox->Folders(); };
         my %keys = map {$_ => 1} keys %$hash;
         return undef    if($@);
-        return undef    unless($keys{$path});
 
-        eval { $folder = $mailbox->Folders($path) };
-        return undef    if($@);
+        $folder = $self->_folders($mailbox, $path) || return undef; 
+
     }
 
     # create an attributes hash
@@ -114,6 +113,26 @@ sub new {
     return $atts;
 }
 
+# Split the path (eg A/B/C) into segments call call the Folder method for each. 
+# Unix style separators (/).
+sub _folders {
+  my ($self,$mailbox, $path)=@_;
+  my @segs = split('/', $path );
+  my $f;
+  foreach my $s ( @segs ) {
+    eval { $f = $f ? $f->Folders($s) : $mailbox->Folders($s);1;}||return undef;
+    return undef if($@); 
+    return undef unless( defined($f) );    
+  }
+  return $f;
+}
+
+=item DESTROY
+
+Empty sub
+
+=cut
+
 sub DESTROY {}
 
 =item first()
@@ -179,7 +198,8 @@ Move a message into this folder.
 sub move {
     my ($self,$message) = @_;
 
-    $message->Move($self->{objfolder});
+    $message->{message}->Move($self->{objfolder});
+    return 1;
 }
 
 =item move_folder($folder)
@@ -191,7 +211,7 @@ Move a folder into this folder.
 sub move_folder {
     my ($self,$folder) = @_;
 
-    $folder->{objfolder}->MoveTo($self->{objfolder});
+    $folder->{objfolder}->Move($self->{objfolder});
 }
 
 =item delete_folder()
@@ -207,6 +227,35 @@ sub delete_folder {
     $self = undef;
 }
 
+=item all_folders
+
+List the names of all folders in this folder.
+
+=cut
+
+sub all_folders {
+  my $self = shift;
+  my $folders = $self->{objfolder}->Folders || [];
+  my @folder_names = ();
+  my $num_folders = $folders->{Count};
+  for( my $i=1; $i <= $num_folders; $i++ ) {
+    push( @folder_names, $folders->Item($i)->Name );
+  }
+  return @folder_names;
+  1;
+}
+
+=item count_items
+
+Return the number of items in the folder.
+
+=cut
+
+sub count_items {
+  my $self = shift;
+  my $count = $self->{objfolder}->Items->Count;
+}
+
 1;
 
 __END__
@@ -269,7 +318,7 @@ RT: L<http://rt.cpan.org/Public/Dist/Display.html?Name=Mail-Outlook>
 
 =head1 COPYRIGHT AND LICENSE
 
-  Copyright  2003-2013 Barbie for Miss Barbell Productions.
+  Copyright E<copy> 2003-2013 Barbie for Miss Barbell Productions.
 
   This distribution is free software; you can redistribute it and/or
   modify it under the Artistic License v2.
